Crate qubit_case

Crate qubit_case 

Qubit Case

Provides naming style detection and conversion helpers for ASCII identifiers.

Structs

CaseStyleError
Error returned when a case style name is unknown.
CaseStyleValidationError
Error returned when a value does not match an expected case style.

Enums

CaseStyle
Naming styles supported by this crate.

Constants

LOWER_CAMEL
Java variable naming style, such as lowerCamel.
LOWER_HYPHEN
XML hyphenated variable naming style, such as lower-hyphen.
LOWER_UNDERSCORE
C++/Python variable naming style, such as lower_underscore.
UPPER_CAMEL
Java and C++ class naming style, such as UpperCamel.
UPPER_UNDERSCORE
Java and C++ constant naming style, such as UPPER_UNDERSCORE.