Qubit Case
Provides naming style detection and conversion helpers for ASCII identifiers.
Structs
- Case
Style Error - Error returned when a case style name is unknown.
- Case
Style Validation Error - Error returned when a value does not match an expected case style.
Enums
- Case
Style - Naming styles supported by this crate.
Constants
- LOWER_
CAMEL - Java variable naming style, such as
lowerCamel. - LOWER_
HYPHEN - XML hyphenated variable naming style, such as
lower-hyphen. - LOWER_
UNDERSCORE - C++/Python variable naming style, such as
lower_underscore. - UPPER_
CAMEL - Java and C++ class naming style, such as
UpperCamel. - UPPER_
UNDERSCORE - Java and C++ constant naming style, such as
UPPER_UNDERSCORE.